@@ -7,7 +7,7 @@ from cmsplugin_bootstrap.plugin_base import BootstrapPluginBase, CSS_MARGIN_STYL
 
 class CarouselPlugin(BootstrapPluginBase):
     name = _("Carousel")
-    render_template = "cms/plugins/bootstrap/carousel.html"
+    render_template = 'cms/plugins/bootstrap/carousel.html'
     child_classes = ['SlidePlugin']
     css_class_choices = (('slide', 'slide'),)
     extra_styles_widget = ExtraStylesWidget(CSS_MARGIN_STYLES + ['width', 'height'])
@@ -18,7 +18,9 @@ plugin_pool.register_plugin(CarouselPlugin)
 
 class SlidePlugin(BootstrapPluginBase):
     name = _("Slide")
+    render_template = 'cms/plugins/bootstrap/carousel-slide.html'
     parent_classes = ['CarouselPlugin']
+    require_parent = True
     child_classes = ['TextPlugin', 'FilerImagePlugin']
     css_class_choices = (('item', 'item'),)
 
